@@ -21,15 +21,18 @@ from concurrent.futures import ThreadPoolExecutor
 from datetime import datetime
 from typing import TYPE_CHECKING
 
+from openlineage.client.serde import Serde
+
 from airflow.listeners import hookimpl
 from airflow.providers.openlineage.extractors import ExtractorManager
-from airflow.providers.openlineage.plugins.adapter import OpenLineageAdapter
+from airflow.providers.openlineage.plugins.adapter import OpenLineageAdapter, RunState
 from airflow.providers.openlineage.utils.utils import (
     get_airflow_run_facet,
     get_custom_facets,
     get_job_name,
     print_warning,
 )
+from airflow.stats import Stats
 from airflow.utils.timeout import timeout
 
 if TYPE_CHECKING:
@@ -82,8 +85,11 @@ class OpenLineageListener:
                 execution_date=task_instance.execution_date,
                 try_number=task_instance.try_number,
             )
+            event_type = RunState.RUNNING.value.lower()
+            operator_name = task.task_type.lower()
 
-            task_metadata = self.extractor_manager.extract_metadata(dagrun, task)
+            with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
+                task_metadata = self.extractor_manager.extract_metadata(dagrun, task)
 
             start_date = task_instance.start_date if task_instance.start_date else datetime.now()
             data_interval_start = (
@@ -91,7 +97,7 @@ class OpenLineageListener:
             )
             data_interval_end = dagrun.data_interval_end.isoformat() if dagrun.data_interval_end else None
 
-            self.adapter.start_task(
+            redacted_event = self.adapter.start_task(
                 run_id=task_uuid,
                 job_name=get_job_name(task),
                 job_description=dag.description,
@@ -108,6 +114,10 @@ class OpenLineageListener:
                     **get_airflow_run_facet(dagrun, dag, task_instance, task, task_uuid),
                 },
             )
+            Stats.gauge(
+                f"ol.event.size.{event_type}.{operator_name}",
+                len(Serde.to_json(redacted_event).encode("utf-8")),
+            )
 
         on_running()
 
@@ -129,14 +139,17 @@ class OpenLineageListener:
                 execution_date=task_instance.execution_date,
                 try_number=task_instance.try_number - 1,
             )
+            event_type = RunState.COMPLETE.value.lower()
+            operator_name = task.task_type.lower()
 
-            task_metadata = self.extractor_manager.extract_metadata(
-                dagrun, task, complete=True, task_instance=task_instance
-            )
+            with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
+                task_metadata = self.extractor_manager.extract_metadata(
+                    dagrun, task, complete=True, task_instance=task_instance
+                )
 
             end_date = task_instance.end_date if task_instance.end_date else datetime.now()
 
-            self.adapter.complete_task(
+            redacted_event = self.adapter.complete_task(
                 run_id=task_uuid,
                 job_name=get_job_name(task),
                 parent_job_name=dag.dag_id,
@@ -144,6 +157,10 @@ class OpenLineageListener:
                 end_time=end_date.isoformat(),
                 task=task_metadata,
             )
+            Stats.gauge(
+                f"ol.event.size.{event_type}.{operator_name}",
+                len(Serde.to_json(redacted_event).encode("utf-8")),
+            )
 
         on_success()
 
@@ -165,14 +182,17 @@ class OpenLineageListener:
                 execution_date=task_instance.execution_date,
                 try_number=task_instance.try_number,
             )
+            event_type = RunState.FAIL.value.lower()
+            operator_name = task.task_type.lower()
 
-            task_metadata = self.extractor_manager.extract_metadata(
-                dagrun, task, complete=True, task_instance=task_instance
-            )
+            with Stats.timer(f"ol.extract.{event_type}.{operator_name}"):
+                task_metadata = self.extractor_manager.extract_metadata(
+                    dagrun, task, complete=True, task_instance=task_instance
+                )
 
             end_date = task_instance.end_date if task_instance.end_date else datetime.now()
 
-            self.adapter.fail_task(
+            redacted_event = self.adapter.fail_task(
                 run_id=task_uuid,
                 job_name=get_job_name(task),
                 parent_job_name=dag.dag_id,
@@ -180,6 +200,10 @@ class OpenLineageListener:
                 end_time=end_date.isoformat(),
                 task=task_metadata,
             )
+            Stats.gauge(
+                f"ol.event.size.{event_type}.{operator_name}",
+                len(Serde.to_json(redacted_event).encode("utf-8")),
+            )
 
         on_failure()
 
